# Ошибки и предложения

## BUGS

1. Если у базового View неуказан NAME_MODULE, то дочерние не переопределяют (ошибка может быть и с другими параметрами
   version & controller)
2. Без декоратора не переопределяется метод API

## Предложения

1. Добавить группировку методов API на уровне класса
2. Добавить поддержку Generic типов